@@ -2,7 +2,7 @@ use super::{deques::Deques, KeyDate, KeyHashDate, ValueEntry};
 use crate::common::{
     deque::{CacheRegion, DeqNode, Deque},
     frequency_sketch::FrequencySketch,
-    time::{Clock, Instant},
+    time::{CheckedTimeOps, Clock, Instant},
     AccessTime,
 };
 
@@ -342,7 +342,7 @@ where
     #[inline]
     fn current_time_from_expiration_clock(&self) -> Instant {
         if let Some(clock) = &self.expiration_clock {
-            clock.now()
+            Instant::new(clock.now())
         } else {
             Instant::now()
         }
@@ -355,7 +355,11 @@ where
         now: Instant,
     ) -> bool {
         if let (Some(ts), Some(tti)) = (entry.last_accessed(), time_to_idle) {
-            return ts + *tti <= now;
+            let checked_add = ts.checked_add(*tti);
+            if checked_add.is_none() {
+                panic!("ttl overflow")
+            }
+            return checked_add.unwrap() <= now;
         }
         false
     }
@@ -367,7 +371,11 @@ where
         now: Instant,
     ) -> bool {
         if let (Some(ts), Some(ttl)) = (entry.last_modified(), time_to_live) {
-            return ts + *ttl <= now;
+            let checked_add = ts.checked_add(*ttl);
+            if checked_add.is_none() {
+                panic!("ttl overflow")
+            }
+            return checked_add.unwrap() <= now;
         }
         false
     }
@@ -387,14 +395,14 @@ where
         if has_free_space {
             // Add the candidate to the deque.
             let key = Rc::clone(&key);
-            let mut entry = cache.get_mut(&key).unwrap();
+            let entry = cache.get_mut(&key).unwrap();
             deqs.push_back_ao(
                 CacheRegion::MainProbation,
                 KeyHashDate::new(Rc::clone(&key), hash, timestamp),
-                &mut entry,
+                entry,
             );
             if self.time_to_live.is_some() {
-                deqs.push_back_wo(KeyDate::new(key, timestamp), &mut entry);
+                deqs.push_back_wo(KeyDate::new(key, timestamp), entry);
             }
         } else {
             let victim = Self::find_cache_victim(deqs, freq);
@@ -414,16 +422,16 @@ where
                     deqs.unlink_node_ao(victim);
                 }
                 // Add the candidate to the deque.
-                let mut entry = cache.get_mut(&key).unwrap();
+                let entry = cache.get_mut(&key).unwrap();
 
                 let key = Rc::clone(&key);
                 deqs.push_back_ao(
                     CacheRegion::MainProbation,
                     KeyHashDate::new(Rc::clone(&key), hash, timestamp),
-                    &mut entry,
+                    entry,
                 );
                 if self.time_to_live.is_some() {
-                    deqs.push_back_wo(KeyDate::new(key, timestamp), &mut entry);
+                    deqs.push_back_wo(KeyDate::new(key, timestamp), entry);
                 }
             } else {
                 // Remove the candidate from the cache.
